@@ -1,7 +1,7 @@
 /* SPDX-License-Identifier: BSD-2-Clause */
 /*
  * dhcpcd - DHCP client daemon
- * Copyright (c) 2006-2024 Roy Marples <roy@marples.name>
+ * Copyright (c) 2006-2025 Roy Marples <roy@marples.name>
  * All rights reserved
 
  * Redistribution and use in source and binary forms, with or without
@@ -524,6 +524,7 @@ ipv4_deladdr(struct ipv4_addr *addr, int keeparp)
 	struct ipv4_state *state;
 	struct ipv4_addr *ap;
 
+	assert(addr != NULL);
 	logdebugx("%s: deleting IP address %s",
 	    addr->iface->name, addr->saddr);
 
@@ -560,28 +561,6 @@ ipv4_deladdr(struct ipv4_addr *addr, int keeparp)
 	return r;
 }
 
-static int
-delete_address(struct interface *ifp)
-{
-	int r;
-	struct if_options *ifo;
-	struct dhcp_state *state;
-
-	state = D_STATE(ifp);
-	ifo = ifp->options;
-	/* The lease could have been added, but the address deleted
-	 * by a 3rd party. */
-	if (state->addr == NULL ||
-	    ifo->options & DHCPCD_INFORM ||
-	    (ifo->options & DHCPCD_STATIC && ifo->req_addr.s_addr == 0))
-		return 0;
-#ifdef ARP
-	arp_freeaddr(ifp, &state->addr->addr);
-#endif
-	r = ipv4_deladdr(state->addr, 0);
-	return r;
-}
-
 struct ipv4_state *
 ipv4_getstate(struct interface *ifp)
 {
@@ -737,8 +716,13 @@ ipv4_addaddr(struct interface *ifp, const struct in_addr *addr,
 	}
 #endif
 
-	if (ia->flags & IPV4_AF_NEW)
+	if (ia->flags & IPV4_AF_NEW) {
 		TAILQ_INSERT_TAIL(&state->addrs, ia, next);
+#if defined(ARP) && !defined(KERNEL_RFC5227)
+		arp_ifannounceaddr(ifp, &ia->addr);
+#endif
+	}
+
 	return ia;
 }
 
@@ -766,7 +750,7 @@ ipv4_applyaddr(void *arg)
 	struct dhcp_state *state = D_STATE(ifp);
 	struct dhcp_lease *lease;
 	struct if_options *ifo = ifp->options;
-	struct ipv4_addr *ia;
+	struct ipv4_addr *ia, *old_ia;
 
 	if (state == NULL)
 		return NULL;
@@ -777,13 +761,10 @@ ipv4_applyaddr(void *arg)
 		    (DHCPCD_EXITING | DHCPCD_PERSISTENT))
 		{
 			if (state->added) {
-				delete_address(ifp);
+				/* Someone might have deleted our address */
+				if (state->addr != NULL)
+					ipv4_deladdr(state->addr, 0);
 				rt_build(ifp->ctx, AF_INET);
-#ifdef ARP
-				/* Announce the preferred address to
-				 * kick ARP caches. */
-				arp_announceaddr(ifp->ctx,&lease->addr);
-#endif
 			}
 			script_runreason(ifp, state->reason);
 		} else
@@ -791,6 +772,9 @@ ipv4_applyaddr(void *arg)
 		return NULL;
 	}
 
+	/* ipv4_dadaddr() will overwrite this, we need it to purge later */
+	old_ia = state->addr;
+
 	ia = ipv4_iffindaddr(ifp, &lease->addr, NULL);
 	/* If the netmask or broadcast is different, re-add the addresss.
 	 * If IP addresses do not have lifetimes, there is a very real chance
@@ -833,20 +817,14 @@ ipv4_applyaddr(void *arg)
 #endif
 
 	/* Delete the old address if different */
-	if (state->addr &&
-	    state->addr->addr.s_addr != lease->addr.s_addr &&
-	    ipv4_iffindaddr(ifp, &lease->addr, NULL))
-		delete_address(ifp);
+	if (old_ia && old_ia->addr.s_addr != lease->addr.s_addr)
+		ipv4_deladdr(old_ia, 0);
 
 	state->addr = ia;
 	state->added = STATE_ADDED;
 
 	rt_build(ifp->ctx, AF_INET);
 
-#ifdef ARP
-	arp_announceaddr(ifp->ctx, &state->addr->addr);
-#endif
-
 	if (state->state == DHS_BOUND) {
 		script_runreason(ifp, state->reason);
 		dhcpcd_daemonise(ifp->ctx);
