@@ -1,7 +1,7 @@
 /* SPDX-License-Identifier: BSD-2-Clause */
 /*
  * Privilege Separation BPF Initiator
- * Copyright (c) 2006-2023 Roy Marples <roy@marples.name>
+ * Copyright (c) 2006-2025 Roy Marples <roy@marples.name>
  * All rights reserved
 
  * Redistribution and use in source and binary forms, with or without
@@ -67,7 +67,7 @@ ps_bpf_recvbpf(void *arg, unsigned short events)
 		.ps_cmd = psp->psp_id.psi_cmd,
 	};
 
-	if (events != ELE_READ)
+	if (!(events & (ELE_READ | ELE_ERROR)))
 		logerrx("%s: unexpected event 0x%04x", __func__, events);
 
 	bpf->bpf_flags &= ~BPF_EOF;
