@@ -1,7 +1,7 @@
 /* SPDX-License-Identifier: BSD-2-Clause */
 /*
  * Socket Address handling for dhcpcd
- * Copyright (c) 2015-2023 Roy Marples <roy@marples.name>
+ * Copyright (c) 2015-2025 Roy Marples <roy@marples.name>
  * All rights reserved
 
  * Redistribution and use in source and binary forms, with or without
@@ -419,11 +419,6 @@ sa_cmp(const struct sockaddr *sa1, const struct sockaddr *sa2)
 	assert(sa1 != NULL);
 	assert(sa2 != NULL);
 
-	/* Treat AF_UNSPEC as the unspecified address. */
-	if ((sa1->sa_family == AF_UNSPEC || sa2->sa_family == AF_UNSPEC) &&
-	    sa_is_unspecified(sa1) && sa_is_unspecified(sa2))
-		return 0;
-
 	if (sa1->sa_family != sa2->sa_family)
 		return sa1->sa_family - sa2->sa_family;
 
